==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/profiles.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
include ("include/posted.inc.php");

if (!KWL_CheckLocalReferer()) {
	KWL_Redirect("$CONF[G_URL]");
}
$head = _PROFILING;
include("include/header.inc.php");

$out = new KWL_Html;
if (!empty($uid)) {
	$ouser = KWL_GetUserInfo("uid",$uid);
	$Author = $ouser['name'];
	$AuthorEmail = KWL_Rot13($ouser['email']);
	$AuthorURL = $ouser['url'];
}
if (empty($Author)) {
	$VAR["Heading"] = _NOUSER;
	$VAR["Content"] = "<br>" . _NOUSER . "<br><br>";
	KWL_DrawMain($VAR);
} else {
	$usr	= $Author;
	if ($usr == $CONF['SiteOwner'] && KWL_Rot13($AuthorEmail) == $CONF['EmailAddress']) $VAR["Heading"] = _SITEOWNER . " : " . $usr;
	else $VAR["Heading"] = _PROFILING . " : " . $usr;
   $ouser = KWL_GetUserInfo("name",urldecode($Author));
	$VAR["Content"]  = $out->table_start("100%");
	$VAR["Content"] .= "<tr><td>" . _NAME . ":</td>\n";
	if (!empty($ouser['name'])) {
		$tmp  = htmlspecialchars($ouser['name']) . " (#$ouser[uid]) ";
		if ($CONF['Private_msg'] && !$CONF['NoLogin_User']) {
         $tmp .= "[ <A HREF=\"priv_msg.php?what=write&uid=$ouser[uid]\">". _SEND_PRIV_MSG ."</A> ]";
      }
	} else $tmp = urldecode($Author);
	$VAR["Content"] .= "<td>$tmp</td></tr>\n";
   
	if (!empty($ouser['uid']) && $CONF['Session'] && !$CONF['NoLogin_User']) {
		$tmp = KWL_SessionGetInfo($ouser['uid']);
      if (empty($tmp)) $tmp = sprintf(_NO_LASTUSED,$CONF['Session_tmout']);
      else $tmp = KWL_strftime($tmp['lastused']);
		
      $VAR["Content"] .= "<tr><td>". _SESSION_LASTUSED .":</td>\n";
		$VAR["Content"] .= "<td>$tmp</td></tr>\n";
	}
   
	$VAR["Content"] .= "<tr><td>" . _URL . ":</td>\n";
	$VAR["Content"] .= "<td>";
	$VAR["Content"] .= $AuthorURL ? "<a target=_new href=\"$AuthorURL\">$AuthorURL</a>" : _NA;
	$VAR["Content"] .= "</td>";
	if (!empty($ouser['profile'])) {
		$VAR["Content"] .= "<tr><td valign=top>". _USER_PROF .":</td>\n";
		$VAR["Content"] .= "<td>" . KWL_ParseContent($ouser['profile'],3) . "</td>";
	}
	if (!empty($ouser['rdate'])) {
		$VAR["Content"] .= "<tr><td valign=top>". _RDATE .":</td>\n";
		$VAR["Content"] .= "<td>". substr($ouser['rdate'],0,10) ."</td>";
	}
	$VAR["Content"] .= "</tr>" . $out->table_end();
	KWL_DrawMain($VAR);
	
	$AuthorEmail = KWL_Rot13($AuthorEmail);

   $my = new KWL_MyPost;
   $my->my_story($Author,$AuthorEmail,$out);
   $my->my_reply($Author,$AuthorEmail,$out);

   $AuthorEmail = KWL_EmailCheck($AuthorEmail);
   if ($AuthorEmail) {
      if ($usr == $CONF['SiteOwner'] && $AuthorEmail == $CONF['EmailAddress']) 
         $VAR["Heading"] = _MAILTOADMIN;
      else $VAR["Heading"]	= _MAILTO;

   $VAR['Content'] = $out->form_start("submit.php","Contact") .
      $out->table_start("100%") .
      "<TR><TD>". _MAIL_SENDER .":</TD>";

   if ($login && is_array($user)) {
      $VAR['Content'] .= "<TD><TD><A HREF=\"$CONF[G_URL]/profiles.php?uid=$user[uid]\">".
         KWL_PrepareHtml($user['name']) ."</A>".
         $out->input_form("hidden","Author",$user['name']).
         $out->input_form("hidden","AuthorEmail",$user['email']).
         "</TD></TR>\n";
   } else {
      $u = KWL_GetCookieUser();
      $VAR['Content'] .= "
   <TD>". $out->input_form("TEXT","Author",$u[0],$size['name'],32) ."</TD>
</TR>
<TR>
	<TD>". _EMAIL .":</TD>
	<TD>". $out->input_form("TEXT","AuthorEmail",$u[1],$size['name'],96) ."</TD>
</TR>";
}
$VAR["Content"] .= "
<TR>
	<TD>". _SUBJECT .":</TD>
	<TD>". $out->input_form("TEXT","Subject",'',$size['titl'],96) ."</TD>
</TR>
<TR>
	<TD>". _MESSAGE .":</TD>
	<TD>". $out->textarea("Message",10,$size['text']) ."
	<BR>". _NOHTML ."</TD>
</TR>
<TR>
	<TD COLSPAN=2 ALIGN=CENTER>
	". $out->input_form("HIDDEN","what","contact")
	. $out->input_form("HIDDEN","MailTo",KWL_PrepareHtml($Author))
	. $out->input_form("HIDDEN","MailToEmail",KWL_PrepareHtml($AuthorEmail))
	. $out->input_form("SUBMIT","SUBMIT",KWL_SubmitButton()) ."
	</TD>
</TR>"
	. $out->table_end() . $out->form_end();
   KWL_DrawMain($VAR);
   unset($VAR);
   }
}
include("include/footer.inc.php");
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/profiles.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
include ("include/posted.inc.php");

if (!KWL_CheckLocalReferer()) {
	KWL_Redirect("$CONF[G_URL]");
}
$head = _PROFILING;
include("include/header.inc.php");

$out = new KWL_Html;
if (!empty($uid)) {
	$ouser = KWL_GetUserInfo("uid",$uid);
	$Author = $ouser['name'];
	$AuthorEmail = KWL_Rot13($ouser['email']);
	$AuthorURL = $ouser['url'];
}
if (empty($Author)) {
	$VAR["Heading"] = _NOUSER;
	$VAR["Content"] = "<br />" . _NOUSER . "<br /><br />";
	KWL_DrawMain($VAR);
} else {
	$usr	= $Author;
	if ($usr == $CONF['SiteOwner'] && KWL_Rot13($AuthorEmail) == $CONF['EmailAddress']) $VAR["Heading"] = _SITEOWNER . " : " . $usr;
	else $VAR["Heading"] = _PROFILING . " : " . $usr;
   $ouser = KWL_GetUserInfo("name",urldecode($Author));
	$VAR["Content"]  = $out->table_start("100%");
	$VAR["Content"] .= "<tr><td>" . _NAME . ":</td>\n";
	if (!empty($ouser['name'])) {
		$tmp  = htmlspecialchars($ouser['name']) . " (#$ouser[uid]) ";
		if ($CONF['Private_msg'] && !$CONF['NoLogin_User']) {
         $tmp .= "[ <a href=\"priv_msg.php?what=write&uid=$ouser[uid]\">". _SEND_PRIV_MSG ."</a> ]";
      }
	} else $tmp = urldecode($Author);
	$VAR["Content"] .= "<td>$tmp</td></tr>\n";
   
	if (!empty($ouser['uid']) && $CONF['Session'] && !$CONF['NoLogin_User']) {
		$tmp = KWL_SessionGetInfo($ouser['uid']);
      if (empty($tmp)) $tmp = sprintf(_NO_LASTUSED,$CONF['Session_tmout']);
      else $tmp = KWL_strftime($tmp['lastused']);
		
      $VAR["Content"] .= "<tr><td>". _SESSION_LASTUSED .":</td>\n";
		$VAR["Content"] .= "<td>$tmp</td></tr>\n";
	}
   
	$VAR["Content"] .= "<tr><td>" . _URL . ":</td>\n";
	$VAR["Content"] .= "<td>";
	$VAR["Content"] .= $AuthorURL ? "<a target=_new href=\"$AuthorURL\">$AuthorURL</a>" : _NA;
	$VAR["Content"] .= "</td>";
	if (!empty($ouser['profile'])) {
		$VAR["Content"] .= "<tr><td valign=top>". _USER_PROF .":</td>\n";
		$VAR["Content"] .= "<td>" . KWL_ParseContent($ouser['profile'],3) . "</td>";
	}
	if (!empty($ouser['rdate'])) {
		$VAR["Content"] .= "<tr><td valign=top>". _RDATE .":</td>\n";
		$VAR["Content"] .= "<td>". substr($ouser['rdate'],0,10) ."</td>";
	}
	$VAR["Content"] .= "</tr>" . $out->table_end();
	KWL_DrawMain($VAR);
	
	$AuthorEmail = KWL_Rot13($AuthorEmail);

   $my = new KWL_MyPost;
   $my->my_story($Author,$AuthorEmail,$out);
   $my->my_reply($Author,$AuthorEmail,$out);

   $AuthorEmail = KWL_EmailCheck($AuthorEmail);
   if ($AuthorEmail) {
      if ($usr == $CONF['SiteOwner'] && $AuthorEmail == $CONF['EmailAddress']) 
         $VAR["Heading"] = _MAILTOADMIN;
      else $VAR["Heading"]	= _MAILTO;

   $VAR['Content'] = $out->form_start("submit.php","Contact") .
      $out->table_start("100%") .
      "<tr><td>". _MAIL_SENDER .": </td>";

   if ($login && is_array($user)) {
      $VAR['Content'] .= "<td><a href=\"$CONF[G_URL]/profiles.php?uid=$user[uid]\">".
         KWL_PrepareHtml($user['name']) ."</a>".
         $out->input_form("hidden","Author",$user['name']).
         $out->input_form("hidden","AuthorEmail",$user['email']).
         "</td></tr>\n";
   } else {
      $u = KWL_GetCookieUser();
      $VAR['Content'] .= "
   <td>". $out->input_form("text","Author",$u[0],$size['name'],32) ."</td>
</tr>
<tr>
	<td>". _EMAIL .":</td>
	<td>". $out->input_form("text","AuthorEmail",$u[1],$size['name'],96) ."</td>
</tr>";
}
$VAR["Content"] .= "
<tr>
	<td>". _SUBJECT .":</td>
	<td>". $out->input_form("text","Subject",'',$size['titl'],96) ."</td>
</tr>
<tr>
	<td>". _MESSAGE .":</td>
	<td>". $out->textarea("Message",10,$size['text']) ."
	<br />". _NOHTML ."</td>
</tr>
<tr>
	<td colspan=\"2\" align=\"center\">
	". $out->input_form("hidden","what","contact")
	. $out->input_form("hidden","MailTo",KWL_PrepareHtml($Author))
	. $out->input_form("hidden","MailToEmail",KWL_PrepareHtml($AuthorEmail))
	. $out->input_form("submit","SUBMIT",KWL_SubmitButton()) ."
	</td>
</tr>"
	. $out->table_end() . $out->form_end();
   KWL_DrawMain($VAR);
   unset($VAR);
   }
}
include("include/footer.inc.php");
?>
